#
# spec file for package wike
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wike
Version:        3.1.1
Release:        1.1
Summary:        A Wikipedia reader for the GNOME Desktop
License:        GPL-3.0-or-later
URL:            https://github.com/hugolabe/Wike
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz

# appstream-glib disabled due to upstream expecting internet connectivity during test.
#BuildRequires:  appstream-glib
BuildRequires:  dbus-1
BuildRequires:  desktop-file-utils
BuildRequires:  gobject-introspection
BuildRequires:  gtk4-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
Requires:       python3-gobject-Gdk
BuildArch:      noarch

%description
Wike is a Wikipedia reader for the GNOME Desktop. Provides access to all the
content of this online encyclopedia in a native application, with a simpler and
distraction-free view of articles.

%package -n gnome-shell-search-provider-wike
Summary:        Wikipedia reader for GNOME -- Search Provider for GNOME Shell
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    (%{name} and gnome-shell)

%description -n gnome-shell-search-provider-wike
This package contains a search provider to enable GNOME Shell to return search
results from wike.

%lang_package

%prep
%autosetup -n Wike-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files
%license COPYING
%doc README.md
%{_bindir}/wike
%{_datadir}/wike/
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/metainfo/*.xml
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/*/*.svg

%files -n gnome-shell-search-provider-wike
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/*.ini
%{_datadir}/dbus-1/services/*.service

%files lang -f %{name}.lang

%changelog
* Fri May  2 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.1:
  * About, Preferences and Languages windows have been migrated to
    the new adaptive dialogs.
  * All message dialogs have been migrated to the new alert
    dialogs.
  * New tooltips have been added to the text search bar.
  * Removed access permission to the user folder in the Flatpak
    sandbox.
  * Minor code adjustments and fixes.
  * Updated translations.
* Sat Sep 28 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.0:
  * About, Preferences and Languages windows have been migrated to
    the new adaptive dialogs.
  * All message dialogs have been migrated to the new alert
    dialogs.
  * New tooltips have been added to the text search bar.
  * Removed access permission to the user folder in the Flatpak
    sandbox.
  * Minor code adjustments and fixes.
  * Updated translations.
- New BuildRequires: gtk4-tools for gtk4-update-icon-cache.
* Tue Mar 26 2024 jun wang <jgwang@suse.com>
- Update to version 3.0.1:
  * Fix type to search issue due to webkit update.
  * Fix status pages issue due to webkit update.
  * Updated translations.
* Tue Mar 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.0:
  * Revamped UI to fit new libadwaita design styles.
  * Side panel redesign that is now located on the left.
  * New left bar that provides quick access to all side panel elements.
  * Search moves to side panel.
  * New design for the languages selection window.
  * Selection mode added to the bookmarks and history lists.
  * New option to hide the tab bar in desktop mode.
  * New option to show all languages in the side panel.
  * Added match counter for text searches.
  * Switching to libsoup for Wikipedia queries.
  * Various improvements and fixes.
  * Updated translations.
* Wed Dec  6 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.0:
  * Added an option to clear personal data on exit.
  * Added an option to restore open articles on start.
  * Enabled navigation with gestures and mouse buttons 8 and 9.
  * Tab overview can now also be used in desktop mode.
  * History items can now be deleted individually.
  * Minor UI changes.
  * Bug fixes.
  * Updated translations.
* Thu May  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.1:
  * Bug fixes.
  * Small UI tweaks.
  * Updated translations.
* Fri Apr 14 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.0.0:
  * Migration to GTK4 + Libadwaita.
  * The search input is now always visible. It also includes an
    indication of the selected language and a button that gives
    access to the search settings.
  * Type to search. Just start typing to find articles.
  * New side panel that provides access to the article table of
    contents, languages, bookmarks and history. It can be used in
    floating or pinned mode.
  * Bookmarks with multiple lists.
  * New view menu that allows you to change the theme, zoom,
    typography and more.
  * Content view now defaults to system font.
  * Responsive design. The user interface now adapts to small
    screens, like phones.
  * Improved status pages (new tab, article not found...).
  * Use of flag icons to help identify languages. This can be
    turned off.
  * New printing option. This also allows export articles using the
    "Print to PDF" option.
  * New app icon.
  * Updated translations.
* Tue Mar 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.3:
  * Added shortcut for Random Article.
  * Small UI tweaks.
  * Bumped to GNOME runtime 43 and WebKit 4.1.
  * Updated translations.
* Tue Oct 25 2022 C J <c.j@tuta.io>
- Update to version 1.8.2:
  * Bug fixes.
  * Added Bulgarian translation.
  * Updated Turkish translation.
* Mon Sep 26 2022 C J <c.j@tuta.io>
- Update to version 1.8.1:
  * Updated translations.
- Changes from version 1.8.0:
  * System light/dark theme support.
  * Updated Wikipedia language list.
  * Bug fixes.
  * Updated translations.
- Changes from version 1.7.2:
  * Updated translations.
- Changes from version 1.7.1:
  * Updated translations.
* Wed Jan 26 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 1.7.0:
  * Desktop searches in multiple languages.
  * Context menu improvements.
  * Updated translations.
* Sat Jan  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
